sqltriples.Query.SingleResults

Package sqltriples :: Module Query :: Class SingleResults |
[show private | hide private]
[frames | no frames]

## Class SingleResults

    AbstractQuery --+
                    |
                Query --+
                        |
                  Results --+
                            |
                           SingleResults

Known Subclasses:
  `Objects`, `Predicates`, `Subjects`

    A class representing a selection of single value results.

Method Summary
Inherited from Results
| ``__init__`(self, store, pattern, expression, functions, ordering, order_by, limit, partial)` Initialise the results object with the given 'store', 'pattern', optional 'expression', optional 'ordering' and 'order_by' descriptions and optional 'limit' criteria.
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`
| ``get_query`(self, index, constraints)` Return a query clause, associated values, and an updated table index (as a 3-tuple) for this object's query defined using the given table 'index' and the supplied, optional 'constraints' text.
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)` Make a subquery for this object using the given 'parent_columns' (indicating the columns which connect with this object's exposed columns), a 'parent_index' (indicating the table index used in the parent query, within which the returned query clause shall be employed), and the current table 'index'.

Class Variable Summary
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net